≈ the.bay.news

Making np.searchsorted up to 25× Faster in NumPy 2.5

blog.scientific-python.org
Making np.searchsorted up to 25× Faster in NumPy 2.5
How vectorizing independent binary searches and reducing per-query state can make np.searchsorted up to 25× faster.

0 comments

Sign in to join the discussion — your thebay.events account works here.

No comments yet.